:orphan:

.. currentmodule:: obspy.core.inventory
.. automodule:: obspy.core.inventory

    .. comment to end block

    Classes & Functions
    -------------------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       ~inventory.read_inventory

    .. comment to end block

    Modules
    -------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       inventory
       network
       station
       channel
       response
       util

    .. comment to end block
